package com.zbf.system.mapper;

import java.util.Date;
import java.util.List;

import org.apache.ibatis.annotations.Param;

import com.baomidou.mybatisplus.core.mapper.BaseMapper; //添加
import com.zbf.system.domain.TCkOrderdetail;
import com.zbf.system.domain.TCkOrders;

/**
 * 出库Mapper接口
 *
 * @author tony
 * @date 2024-06-24
 */
public interface TCkOrdersMapper extends BaseMapper<TCkOrders> //修改
{
    /**
     * 查询出库
     *
     * @param id 出库主键
     * @return 出库
     */
    public TCkOrders selectTCkOrdersById(String id);
    public TCkOrders selectOnes(String id);
    public TCkOrders get(String id);

    public TCkOrders selectTCkOrdersByOrderId(String id);

    public TCkOrders selectTCkOrdersByDeliveryId(String id);

    /**
     * 查询出库列表
     *
     * @param tCkOrders 出库
     * @return 出库集合
     */
    public List<TCkOrders> selectTCkOrdersList(TCkOrders tCkOrders);

    /**
     * 新增出库
     *
     * @param tCkOrders 出库
     * @return 结果
     */
    public int insertTCkOrders(TCkOrders tCkOrders);

    /**
     * 修改出库
     *
     * @param tCkOrders 出库
     * @return 结果
     */
    public int updateTCkOrders(TCkOrders tCkOrders);

    public int updateResultCode(TCkOrders tCkOrders);

    /**
     * 删除出库
     *
     * @param id 出库主键
     * @return 结果
     */
    public int deleteTCkOrdersById(String id);

    /**
     * 批量删除出库
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTCkOrdersByIds(String[] ids);

    /**
     * 批量启用出库
     *
     * @param ids 需要启用的数据主键集合
     * @return 结果
     */
    public int enableTCkOrdersByIds(String[] ids);

    /**
     * 批量禁用出库
     *
     * @param ids 需要禁用的数据主键集合
     * @return 结果
     */
    public int disabledTCkOrdersByIds(String[] ids);


    /**
     * 批量删除出库物料明细
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTCkOrderdetailByOrderIds(String[] ids);

    /**
     * 批量新增出库物料明细
     *
     * @param tCkOrderdetailList 出库物料明细列表
     * @return 结果
     */
    public int batchTCkOrderdetail(List<TCkOrderdetail> tCkOrderdetailList);


    /**
     * 通过出库主键删除出库物料明细信息
     *
     * @param id 出库ID
     * @return 结果
     */
    public int deleteTCkOrderdetailByOrderId(String id);
    /**
     * 批量审核出库单
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int auditTCkOrdersByIds(@Param("ids") String[] ids, @Param("auditMan") String auditMan, @Param("auditDate") Date auditDate);

    int homeCount(TCkOrders tCkOrders);
    int updateConfirmStatus(TCkOrders tCkOrders);

    Long queryTotalCallShelvesNum(TCkOrderdetail tCkOrderdetail);

    List<TCkOrders> exportTCkOrdersList(TCkOrders tCkOrders);


}
